@@ -1,4 +1,5 @@
 #!/bin/sh
-[ -f /usr/share/acpi-support/key-constants ] || exit 0
+
+test -f /usr/share/acpi-support/key-constants || exit 0 
 . /usr/share/acpi-support/key-constants
 acpi_fakekey $KEY_BRIGHTNESSDOWN
