@@ -4,7 +4,7 @@ test -f /usr/share/acpi-support/key-constants || exit 0
 
 . /usr/share/acpi-support/policy-funcs
 
-if [ -z "$*" ] && [ `CheckPolicy` = 0 ]; then
+if [ -z "$*" ] && ( [ `CheckPolicy` = 0 ] || CheckUPowerPolicy ); then
     exit;
 fi
 
