@@ -1,4 +1,6 @@
-#!/bin/bash
+#!/bin/sh
+
+test -f /usr/share/acpi-support/key-constants || exit 0
 
 . /etc/default/acpi-support
 . /usr/share/acpi-support/power-funcs
